:root {
  --blue: #0067b1;
  --blue-deep: #004f8b;
  --cyan: #00a5c8;
  --aqua: #8fd8df;
  --green: #57b34a;
  --orange: #f29c38;
  --ink: #1f2b35;
  --muted: #5f6e7a;
  --line: #d9e3ea;
  --soft: #f4f9fb;
  --white: #fff;
  --shadow: 0 18px 45px rgba(25, 67, 91, .12);
}

* {
  box-sizing: border-box;
}

html {
  scroll-behavior: smooth;
}

body {
  margin: 0;
  color: var(--ink);
  font-family: "Noto Sans JP", "Hiragino Kaku Gothic ProN", "Yu Gothic", Meiryo, sans-serif;
  font-weight: 400;
  line-height: 1.75;
  background: var(--white);
  overflow-x: hidden;
}

a {
  color: inherit;
}

img {
  max-width: 100%;
  display: block;
}

.site-header {
  position: sticky;
  top: 0;
  z-index: 20;
  background: rgba(255, 255, 255, .96);
  border-bottom: 1px solid var(--line);
  backdrop-filter: blur(12px);
}

.header-inner,
.footer-inner {
  width: min(1120px, calc(100% - 40px));
  margin: 0 auto;
}

.header-inner {
  min-height: 72px;
  display: flex;
  align-items: center;
  justify-content: space-between;
  gap: 28px;
}

.brand,
.footer-brand {
  display: inline-flex;
  align-items: center;
  gap: 12px;
  color: var(--ink);
  font-weight: 700;
  text-decoration: none;
}

.brand-mark {
  color: var(--blue);
  font-size: 22px;
  font-weight: 800;
}

.brand-name {
  font-size: 15px;
}

.global-nav,
.footer-nav {
  display: flex;
  flex-wrap: wrap;
  gap: 20px;
  color: var(--muted);
  font-size: 14px;
  font-weight: 700;
}

.global-nav a,
.footer-nav a {
  text-decoration: none;
}

.global-nav a:hover,
.footer-nav a:hover,
.text-link:hover {
  color: var(--blue);
}

.home-hero {
  min-height: 430px;
  display: grid;
  align-items: center;
  background:
    radial-gradient(circle at 82% 32%, rgba(143, 216, 223, .42) 0 18%, rgba(143, 216, 223, 0) 36%),
    linear-gradient(110deg, #005c9d 0%, #0078ad 46%, #e8f7fa 100%);
  color: var(--white);
}

.home-hero__inner {
  width: min(1120px, calc(100% - 40px));
  margin: 0 auto;
  padding: 70px 0;
}

.home-hero h1,
.cba-hero h1 {
  margin: 12px 0 18px;
  line-height: 1.18;
  letter-spacing: 0;
  font-family: "Noto Serif JP", "Noto Sans JP", serif;
  font-weight: 700;
}

.home-hero h1 {
  max-width: 720px;
  font-size: clamp(34px, 6vw, 58px);
}

.home-hero p {
  max-width: 650px;
  font-size: 18px;
}

.eyebrow {
  margin: 0;
  color: var(--cyan);
  font-size: 13px;
  font-weight: 800;
  letter-spacing: 0;
  text-transform: uppercase;
}

.home-hero .eyebrow,
.cba-hero .eyebrow {
  color: #dff8ff;
}

.cba-hero .eyebrow {
  color: var(--cyan);
}

.section {
  padding: 78px 0;
}

.section--soft {
  background: var(--soft);
}

.section--accent {
  background: #eaf7f6;
}

.section-inner {
  width: min(1120px, calc(100% - 40px));
  margin: 0 auto;
}

.section-inner.narrow {
  width: min(900px, calc(100% - 40px));
}

.section-heading {
  margin-bottom: 34px;
}

.section-heading h2 {
  margin: 8px 0 10px;
  font-size: clamp(28px, 4vw, 42px);
  line-height: 1.25;
}

.section-heading p:not(.eyebrow) {
  max-width: 780px;
  color: var(--muted);
}

.subheading {
  margin: 0 0 20px;
  padding-left: 16px;
  border-left: 5px solid var(--blue);
  font-size: 24px;
}

.project-list,
.article-list,
.member-list,
.topic-grid {
  display: grid;
  gap: 18px;
}

.project-banner {
  min-height: 150px;
  display: grid;
  align-content: center;
  gap: 4px;
  padding: 28px 32px;
  overflow: hidden;
  position: relative;
  color: var(--white);
  text-decoration: none;
  background: linear-gradient(115deg, var(--blue), var(--cyan));
  border-radius: 6px;
  box-shadow: var(--shadow);
}

.project-banner::after {
  content: "";
  position: absolute;
  inset: 0 0 0 auto;
  width: 44%;
  background: linear-gradient(90deg, rgba(255,255,255,0), rgba(255,255,255,.24));
}

.project-banner--thinking {
  background: linear-gradient(115deg, #10826f, #65ba48);
}

.project-banner--cba {
  background:
    radial-gradient(circle at 82% 38%, rgba(255, 255, 255, .28) 0 9%, rgba(255, 255, 255, 0) 18%),
    linear-gradient(115deg, #00558f 0%, #0078a7 52%, #60bec7 100%);
}

.project-banner--cba::before {
  content: "";
  position: absolute;
  right: 28px;
  top: 26px;
  width: min(280px, 34%);
  height: 96px;
  border: 1px solid rgba(255,255,255,.45);
  border-radius: 6px;
  background:
    linear-gradient(90deg, rgba(255,255,255,.68) 0 22%, transparent 22% 100%) 22px 22px / 118px 8px no-repeat,
    linear-gradient(90deg, rgba(255,255,255,.44) 0 32%, transparent 32% 100%) 22px 42px / 160px 8px no-repeat,
    linear-gradient(90deg, rgba(255,255,255,.34) 0 20%, transparent 20% 100%) 22px 62px / 138px 8px no-repeat,
    rgba(255,255,255,.12);
}

.project-banner__label {
  font-size: 14px;
  font-weight: 800;
}

.project-banner__title {
  max-width: 760px;
  font-size: clamp(22px, 4vw, 33px);
  font-weight: 800;
  line-height: 1.35;
}

.project-banner__text {
  max-width: 720px;
  font-size: 15px;
}

.cba-hero {
  min-height: 620px;
  position: relative;
  display: grid;
  align-items: end;
  overflow: hidden;
  color: var(--ink);
  background:
    radial-gradient(circle at 78% 26%, rgba(143, 216, 223, .42) 0 17%, rgba(143, 216, 223, 0) 31%),
    linear-gradient(110deg, #f7fbfd 0%, #edf7f9 54%, #dceff3 100%);
}

.cba-hero__media {
  position: absolute;
  inset: 0;
  z-index: 0;
}

.cba-hero__media::after {
  content: "";
  position: absolute;
  inset: 0;
  background:
    linear-gradient(90deg, rgba(247, 251, 253, .98) 0 42%, rgba(247, 251, 253, .72) 58%, rgba(247, 251, 253, .28) 100%),
    repeating-linear-gradient(0deg, rgba(0, 103, 177, .035) 0 1px, transparent 1px 28px),
    repeating-linear-gradient(90deg, rgba(0, 103, 177, .035) 0 1px, transparent 1px 28px);
  z-index: 0;
}

.cba-visual {
  position: absolute;
  z-index: 1;
  right: max(36px, calc((100vw - 1120px) / 2));
  top: 116px;
  width: min(550px, 47vw);
  height: 390px;
  color: var(--blue-deep);
}

.assessment-window {
  position: absolute;
  right: 48px;
  top: 42px;
  width: 390px;
  min-height: 250px;
  padding: 54px 24px 24px;
  background: rgba(255, 255, 255, .86);
  border: 1px solid rgba(0, 103, 177, .2);
  border-radius: 8px;
  box-shadow: 0 24px 52px rgba(35, 76, 101, .16);
}

.window-bar {
  position: absolute;
  inset: 0 0 auto;
  height: 34px;
  display: flex;
  align-items: center;
  gap: 7px;
  padding-left: 16px;
  border-bottom: 1px solid rgba(0, 103, 177, .12);
}

.window-bar span,
.node {
  display: block;
  border-radius: 50%;
}

.window-bar span {
  width: 8px;
  height: 8px;
  background: #b9d7e4;
}

.item-panel,
.process-panel,
.feedback-card {
  background: #fff;
  border: 1px solid rgba(0, 103, 177, .16);
  border-radius: 6px;
}

.item-panel {
  padding: 18px;
}

.process-panel {
  margin-top: 14px;
  padding: 16px 18px;
}

.mini-label {
  margin: 0 0 10px;
  color: var(--cyan);
  font-size: 11px;
  font-weight: 900;
  letter-spacing: 0;
  text-transform: uppercase;
}

.question-lines {
  display: grid;
  gap: 9px;
  margin-bottom: 18px;
}

.question-lines span {
  height: 8px;
  border-radius: 99px;
  background: #dbeaf0;
}

.question-lines span:nth-child(1) {
  width: 86%;
}

.question-lines span:nth-child(2) {
  width: 72%;
}

.question-lines span:nth-child(3) {
  width: 48%;
}

.choice-grid {
  display: grid;
  grid-template-columns: repeat(4, 1fr);
  gap: 10px;
}

.choice {
  height: 40px;
  border: 1px solid #d1e4ec;
  border-radius: 5px;
  background: #f6fbfc;
}

.choice.selected {
  background: rgba(0, 165, 200, .14);
  border-color: var(--cyan);
}

.choice.active {
  background: rgba(242, 156, 56, .16);
  border-color: var(--orange);
}

.log-row {
  display: grid;
  grid-template-columns: 1fr 72px;
  gap: 14px;
  align-items: center;
  margin-top: 9px;
}

.log-row span,
.log-row i,
.feedback-card span {
  display: block;
  height: 7px;
  border-radius: 99px;
  background: #dbeaf0;
}

.log-row i {
  background: var(--aqua);
}

.data-map {
  position: absolute;
  inset: 0;
}

.node {
  position: absolute;
  width: 16px;
  height: 16px;
  background: var(--cyan);
  box-shadow: 0 0 0 7px rgba(0, 165, 200, .12);
}

.node-a { left: 34px; top: 88px; }
.node-b { right: 0; top: 20px; background: var(--orange); box-shadow: 0 0 0 7px rgba(242, 156, 56, .13); }
.node-c { left: 0; bottom: 70px; background: var(--green); box-shadow: 0 0 0 7px rgba(87, 179, 74, .12); }
.node-d { right: 54px; bottom: 52px; }

.line {
  position: absolute;
  height: 1px;
  background: rgba(0, 103, 177, .24);
  transform-origin: left center;
}

.line-a { left: 50px; top: 96px; width: 440px; transform: rotate(-9deg); }
.line-b { left: 16px; bottom: 82px; width: 390px; transform: rotate(-26deg); }
.line-c { left: 270px; top: 138px; width: 230px; transform: rotate(42deg); }

.feedback-card {
  position: absolute;
  left: 44px;
  bottom: 8px;
  width: 218px;
  padding: 18px;
  box-shadow: 0 18px 34px rgba(35, 76, 101, .12);
}

.feedback-card strong {
  display: block;
  margin-bottom: 12px;
  font-size: 17px;
}

.cba-hero__content {
  width: min(1120px, calc(100% - 40px));
  margin: 0 auto;
  padding: 112px 0 92px;
  position: relative;
  z-index: 2;
}

.cba-hero h1 {
  max-width: 680px;
  color: var(--blue-deep);
  font-size: clamp(42px, 6.2vw, 68px);
}

.cba-hero h1 span {
  color: var(--ink);
  font-family: "Noto Sans JP", sans-serif;
  font-size: .48em;
  font-weight: 900;
}

.cba-hero__content p:last-child {
  max-width: 560px;
  color: #334653;
  font-size: 18px;
}

.page-nav {
  width: 100%;
  display: flex;
  flex-wrap: wrap;
  justify-content: center;
  gap: 10px;
  padding: 18px 20px;
  background: var(--white);
  border-bottom: 1px solid var(--line);
}

.page-nav a {
  padding: 9px 14px;
  color: var(--blue-deep);
  font-size: 14px;
  font-weight: 800;
  text-decoration: none;
  border: 1px solid var(--line);
  border-radius: 999px;
}

.two-column {
  display: grid;
  grid-template-columns: repeat(2, minmax(0, 1fr));
  gap: 28px;
  margin-bottom: 28px;
}

.text-block,
.topic-card,
.article-card,
.output-group,
.member-card,
.notice-panel,
.collaboration-panel {
  background: var(--white);
  border: 1px solid var(--line);
  border-radius: 6px;
}

.text-block {
  padding: 30px;
}

.text-block h3,
.topic-card h3,
.output-group h3,
.notice-panel h3,
.collaboration-panel h3 {
  margin: 0 0 12px;
  color: var(--blue-deep);
  font-size: 22px;
}

.topic-grid {
  grid-template-columns: repeat(3, minmax(0, 1fr));
}

.topic-card {
  padding: 26px;
}

.plain-list {
  margin: 0;
  padding-left: 20px;
}

.text-link {
  color: var(--blue);
  font-weight: 800;
}

.article-list {
  grid-template-columns: repeat(2, minmax(0, 1fr));
}

.article-card {
  min-height: 220px;
  display: flex;
  flex-direction: column;
  padding: 26px;
  text-decoration: none;
  transition: transform .18s ease, box-shadow .18s ease;
}

.article-card:hover {
  transform: translateY(-3px);
  box-shadow: var(--shadow);
}

.status {
  width: fit-content;
  margin-bottom: 14px;
  padding: 3px 10px;
  color: var(--white);
  background: var(--orange);
  border-radius: 999px;
  font-size: 12px;
  font-weight: 800;
}

.article-card h3 {
  margin: 0 0 10px;
  font-size: 22px;
  line-height: 1.45;
}

.article-card p {
  margin: 0 0 18px;
  color: var(--muted);
}

.byline {
  margin-top: auto;
  color: var(--blue-deep);
  font-size: 13px;
  font-weight: 800;
}

.output-list {
  display: grid;
  gap: 14px;
}

.output-group {
  display: grid;
  grid-template-columns: 180px 1fr;
  align-items: start;
  gap: 20px;
  padding: 22px 26px;
}

.output-group h3,
.output-group p {
  margin: 0;
}

.member-list {
  grid-template-columns: repeat(4, minmax(0, 1fr));
}

.member-card {
  padding: 24px;
}

.member-card h3 {
  margin: 6px 0 0;
  font-size: 22px;
}

.role,
.note {
  margin: 0;
  color: var(--muted);
  font-size: 14px;
}

.note {
  margin-top: 18px;
}

.notice-panel,
.collaboration-panel {
  padding: 34px;
  box-shadow: var(--shadow);
}

.button-link {
  display: inline-flex;
  align-items: center;
  justify-content: center;
  min-height: 46px;
  margin-top: 12px;
  padding: 10px 20px;
  color: var(--white);
  background: var(--blue);
  border-radius: 999px;
  font-weight: 800;
  text-decoration: none;
}

.site-footer {
  padding: 48px 0;
  color: var(--white);
  background: #243746;
}

.footer-inner {
  display: flex;
  justify-content: space-between;
  gap: 30px;
}

.footer-brand,
.site-footer a {
  color: var(--white);
}

.site-footer p {
  margin: 8px 0 0;
  color: #d8e2e8;
}

/* Thinking project inspired layout for the CBA landing page */
.thinking-style {
  --thinking-blue: #0071bc;
  --thinking-sky: #e7f6fb;
  --thinking-green: #14a06f;
  --thinking-yellow: #f4a52d;
  --thinking-border: #d5e5ed;
  color: #10243a;
  font-family: "Noto Sans JP", "Hiragino Kaku Gothic ProN", "Yu Gothic", Meiryo, sans-serif;
  background: #fff;
}

.thinking-header {
  background: #fff;
  border-bottom: 1px solid var(--thinking-border);
}

.thinking-header__inner {
  width: min(1120px, calc(100% - 40px));
  margin: 0 auto;
  padding: 18px 0 12px;
}

.thinking-header__logos {
  display: flex;
  align-items: center;
  gap: 18px;
}

.thinking-brand {
  color: #0068b7;
  font-size: 25px;
  font-weight: 900;
  line-height: 1;
  text-decoration: none;
}

.thinking-site {
  color: #111;
  font-size: 15px;
  font-weight: 700;
  text-decoration: none;
}

.thinking-page-id {
  margin: 16px 0 0;
  padding: 14px 20px;
  color: #fff;
  background: linear-gradient(90deg, #0069aa, #00a7c8);
  border-radius: 0 22px 22px 0;
  font-size: clamp(19px, 3vw, 30px);
  line-height: 1.35;
  overflow-wrap: anywhere;
}

.thinking-page-id a {
  color: inherit;
  text-decoration: none;
}

.thinking-gnav {
  background: #f7fbfd;
  border-top: 1px solid var(--thinking-border);
}

.thinking-gnav ul {
  width: min(1120px, calc(100% - 40px));
  margin: 0 auto;
  padding: 0;
  display: grid;
  grid-template-columns: repeat(6, 1fr);
  list-style: none;
}

.thinking-gnav li {
  border-left: 1px solid var(--thinking-border);
}

.thinking-gnav li:last-child {
  border-right: 1px solid var(--thinking-border);
}

.thinking-gnav a {
  min-height: 112px;
  display: grid;
  place-items: center;
  align-content: center;
  gap: 8px;
  color: #004f84;
  font-size: 14px;
  font-weight: 800;
  line-height: 1.45;
  text-align: center;
  text-decoration: none;
}

.thinking-gnav a:hover {
  background: #eef8fb;
}

.nav-icon {
  width: 42px;
  height: 42px;
  display: grid;
  place-items: center;
  color: #fff;
  background: var(--thinking-blue);
  border-radius: 50%;
  font-size: 13px;
  font-weight: 900;
}

.thinking-main {
  overflow: hidden;
}

.thinking-hero {
  padding: 36px 0 0;
  background: linear-gradient(180deg, #fff 0, #fff 70%, var(--thinking-sky) 70%, var(--thinking-sky) 100%);
}

.thinking-hero__inner {
  width: min(1120px, calc(100% - 40px));
  min-height: 470px;
  margin: 0 auto;
  position: relative;
  display: grid;
  grid-template-columns: minmax(0, 1fr) minmax(420px, 520px);
  align-items: center;
  gap: 40px;
  padding: 54px 56px;
  overflow: hidden;
  background:
    radial-gradient(circle at 82% 20%, rgba(255,255,255,.52) 0 16%, rgba(255,255,255,0) 34%),
    linear-gradient(120deg, #006ba8 0%, #0095b8 50%, #bfeaf0 100%);
  border-radius: 0;
}

.thinking-hero__inner::before {
  content: "";
  position: absolute;
  inset: 0;
  background:
    repeating-linear-gradient(0deg, rgba(255,255,255,.16) 0 1px, transparent 1px 30px),
    repeating-linear-gradient(90deg, rgba(255,255,255,.13) 0 1px, transparent 1px 30px);
  opacity: .72;
}

.thinking-hero__copy,
.thinking-hero__visual {
  min-width: 0;
  position: relative;
  z-index: 1;
}

.thinking-kicker {
  margin: 0 0 16px;
  color: #fff;
  font-size: 15px;
  font-weight: 900;
  letter-spacing: 0;
  text-transform: uppercase;
}

.thinking-hero__label {
  width: fit-content;
  margin: 0 0 18px;
  padding: 7px 14px;
  color: #005b91;
  background: rgba(255,255,255,.92);
  font-weight: 900;
}

.thinking-hero h2 {
  margin: 0 0 22px;
  color: #fff;
  font-size: clamp(38px, 5.7vw, 66px);
  font-weight: 900;
  line-height: 1.17;
  letter-spacing: 0;
}

.thinking-hero h2 span {
  display: block;
  margin-top: 8px;
  font-size: .44em;
  overflow-wrap: anywhere;
}

.thinking-hero__copy p:last-child {
  max-width: 620px;
  margin: 0;
  color: #fff;
  font-size: 18px;
  font-weight: 700;
}

.thinking-hero__visual {
  min-height: 350px;
}

.cba-visual--thinking {
  position: relative;
  inset: auto;
  width: 100%;
  height: 350px;
  color: var(--blue-deep);
}

.cba-visual--thinking .assessment-window {
  right: 8px;
  top: 34px;
}

.thinking-section {
  padding: 82px 0;
}

.thinking-section--bg {
  background:
    radial-gradient(circle at 90% 0, rgba(0, 167, 200, .11) 0 20%, transparent 36%),
    #f2f8fb;
}

.thinking-contents {
  width: min(1000px, calc(100% - 40px));
  margin: 0 auto;
}

.thinking-heading {
  margin: 0 0 30px;
  color: #10243a;
  font-size: clamp(31px, 4.3vw, 46px);
  font-weight: 900;
  line-height: 1.35;
  text-align: center;
}

.thinking-heading--line {
  padding-bottom: 20px;
  position: relative;
}

.thinking-heading--line::after {
  content: "";
  position: absolute;
  left: 50%;
  bottom: 0;
  width: 72px;
  height: 4px;
  background: var(--thinking-blue);
  transform: translateX(-50%);
}

.thinking-lead {
  max-width: 900px;
  margin: 0 auto 30px;
  font-size: 18px;
  line-height: 2;
}

.aim-list {
  margin: 36px auto 0;
  padding: 0;
  display: grid;
  gap: 18px;
  list-style: none;
}

.aim-list li {
  display: grid;
  grid-template-columns: 72px 1fr;
  align-items: center;
  gap: 22px;
  padding: 24px 30px;
  background: #fff;
  border: 1px solid var(--thinking-border);
  border-radius: 0;
  font-size: 18px;
  font-weight: 800;
  line-height: 1.7;
}

.aim-list span {
  width: 54px;
  height: 54px;
  display: grid;
  place-items: center;
  color: #fff;
  background: var(--thinking-blue);
  border-radius: 50%;
  font-weight: 900;
}

.thinking-detail {
  display: grid;
  grid-template-columns: repeat(2, minmax(0, 1fr));
  gap: 22px;
}

.thinking-detail section {
  padding: 28px;
  border: 1px solid var(--thinking-border);
  background: #fff;
}

.thinking-detail section:last-child {
  grid-column: 1 / -1;
}

.thinking-detail h3 {
  margin: 0 0 12px;
  color: #0060a4;
  font-size: 22px;
}

.thinking-detail p {
  margin: 0;
}

.thinking-text-link {
  display: inline-block;
  margin-top: 14px;
  color: #0060a4;
  font-weight: 900;
}

.news-list {
  border-top: 1px solid var(--thinking-border);
}

.news-item {
  min-height: 92px;
  display: grid;
  grid-template-columns: 120px 130px 1fr 28px;
  gap: 18px;
  align-items: center;
  padding: 20px 0;
  color: inherit;
  text-decoration: none;
  border-bottom: 1px solid var(--thinking-border);
}

.news-item::after {
  content: ">";
  width: 28px;
  height: 28px;
  display: grid;
  place-items: center;
  color: #fff;
  background: var(--thinking-blue);
  border-radius: 50%;
  font-weight: 900;
}

.itemCat {
  display: inline-grid;
  place-items: center;
  min-height: 30px;
  padding: 4px 10px;
  color: #fff;
  background: var(--thinking-green);
  font-size: 12px;
  font-weight: 900;
  text-align: center;
}

.itemCat.--cat02 {
  background: var(--thinking-yellow);
}

.itemDate {
  color: #4e6575;
  font-size: 14px;
  font-weight: 800;
}

.itemText {
  font-size: 16px;
  font-weight: 800;
  line-height: 1.7;
}

.output-table {
  border-top: 1px solid var(--thinking-border);
}

.output-table section {
  display: grid;
  grid-template-columns: 180px 1fr;
  gap: 24px;
  padding: 22px 0;
  border-bottom: 1px solid var(--thinking-border);
}

.output-table h3,
.output-table p {
  margin: 0;
}

.output-table h3 {
  color: #0060a4;
  font-size: 20px;
}

.member-message {
  max-width: 900px;
  margin: 0 auto;
  line-height: 2;
}

.member-names {
  margin: 34px 0 0;
  padding: 0;
  display: grid;
  grid-template-columns: repeat(2, minmax(0, 1fr));
  gap: 16px;
  list-style: none;
}

.member-names li {
  padding: 20px 24px;
  background: #f7fbfd;
  border-left: 5px solid var(--thinking-blue);
}

.member-names strong,
.member-names span {
  display: block;
}

.member-names strong {
  font-size: 20px;
}

.member-names span {
  color: #4e6575;
  font-size: 14px;
  font-weight: 700;
}

.author__btn01 {
  margin: 34px 0 0;
  text-align: center;
}

.author__btn01 a {
  min-width: 260px;
  display: inline-flex;
  align-items: center;
  justify-content: center;
  min-height: 56px;
  padding: 12px 28px;
  color: #fff;
  background: var(--thinking-blue);
  font-weight: 900;
  text-decoration: none;
}

.author-message-like {
  max-width: 900px;
  margin: 0 auto;
  font-size: 18px;
  line-height: 2.1;
}

.thinking-footer {
  background: #243746;
  color: #fff;
}

.thinking-footer__nav {
  width: min(1120px, calc(100% - 40px));
  margin: 0 auto;
  padding: 40px 0;
}

.thinking-footer__nav ul {
  margin: 0;
  padding: 0;
  display: grid;
  grid-template-columns: repeat(3, 1fr);
  gap: 1px;
  list-style: none;
}

.thinking-footer__nav a {
  display: block;
  padding: 18px 20px;
  color: #fff;
  background: rgba(255,255,255,.08);
  font-weight: 800;
  text-decoration: none;
}

.thinking-footer__global {
  display: flex;
  align-items: center;
  justify-content: space-between;
  gap: 24px;
  padding: 24px max(20px, calc((100% - 1120px) / 2));
  background: #102433;
}

.thinking-footer__global a {
  color: #fff;
  font-size: 22px;
  font-weight: 900;
  text-decoration: none;
}

/* Header/footer regulation style based on the thinking project page */
.cba-reg-header {
  background: #fff;
  border-bottom: 1px solid #d1e0e8;
}

.cba-reg-header .l-contents {
  width: min(1120px, calc(100% - 40px));
  margin: 0 auto;
}

.cba-reg-header .l-header__global__links {
  display: flex;
  justify-content: flex-end;
  padding-top: 10px;
}

.cba-reg-header .l-header__global-link {
  margin: 0;
  padding: 0;
  display: flex;
  gap: 22px;
  list-style: none;
}

.cba-reg-header .l-header__global-link__target {
  color: #6f7b86;
  font-size: 12px;
  font-weight: 700;
}

.cba-reg-header .l-header__primarywrap {
  display: flex;
  align-items: stretch;
  padding-top: 6px;
}

.cba-reg-header .l-header__logo-wrap {
  flex: 0 0 386px;
}

.cba-reg-header .logo {
  display: flex;
  align-items: center;
  gap: 14px;
}

.cba-reg-header .header__brandId img {
  width: 108px;
  height: auto;
}

.cba-reg-header .header__siteId img {
  width: 232px;
  height: auto;
}

.cba-reg-header a {
  text-decoration: none;
}

.cba-page-id {
  margin: 12px 0 0;
}

.cba-page-id .header__pageIdLink {
  display: block;
  overflow: hidden;
  border-radius: 0;
}

.cba-page-id .header__pageIdLinkImg {
  width: 100%;
  max-width: 390px;
  height: auto;
  display: block;
}

.cba-reg-header .header__gNav {
  flex: 1 1 auto;
  margin-top: 0;
  margin-left: 22px;
  background: #fff;
  border-top: 0;
}

.cba-reg-header .navList__wrap {
  width: 100%;
  height: 100%;
  margin: 0;
}

.cba-reg-header .navList {
  height: 100%;
  margin: 0;
  padding: 0;
  display: grid;
  grid-template-columns: repeat(6, 1fr);
  list-style: none;
}

.cba-reg-header .navList__item {
  border-left: 1px solid #bfc9d1;
}

.cba-reg-header .navList__item:last-child {
  border-right: 1px solid #bfc9d1;
}

.cba-reg-header .navList__itemLink {
  min-height: 106px;
  display: grid;
  place-items: center;
  align-content: center;
  gap: 6px;
  padding: 8px 8px 10px;
  color: #111;
  font-size: 15px;
  font-weight: 900;
  line-height: 1.25;
  text-align: center;
  transition: color .2s ease;
}

.cba-reg-header .navList__itemLink:hover,
.cba-reg-header .navList__itemLink:focus-visible {
  background: transparent;
  color: #0071bc;
}

.cba-nav-icon {
  width: 40px;
  height: 40px;
  display: grid;
  place-items: center;
  border-radius: 50%;
  background: #0093b8;
  overflow: hidden;
}

.cba-nav-icon:empty::before {
  content: "";
  width: 18px;
  height: 18px;
  border: 2px solid #fff;
  border-radius: 5px;
  opacity: .9;
}

.cba-nav-icon img {
  width: 100%;
  height: 100%;
  object-fit: contain;
  display: block;
}

.cba-nav-icon--columns:empty::before {
  border-radius: 50%;
  border-width: 2px;
  box-shadow: inset 0 -6px 0 rgba(255,255,255,.28);
}

.cba-nav-icon--outputs:empty::before {
  width: 17px;
  height: 17px;
  border-radius: 3px;
  transform: rotate(-14deg);
}

.cba-nav-icon--members:empty::before {
  width: 16px;
  height: 16px;
  border-radius: 50%;
}

.cba-nav-icon--kaken:empty::before {
  width: 15px;
  height: 20px;
  border-radius: 3px;
}

.cba-nav-icon--collaboration:empty::before {
  width: 18px;
  height: 14px;
  border-radius: 2px;
}

.cba-reg-footer {
  background: #fff;
  color: #25384a;
}

.cba-reg-footer .l-footer__global {
  padding: 34px 0;
  background: #fff;
  border-top: 1px solid #e3edf2;
}

.cba-footer-global {
  width: min(1120px, calc(100% - 40px));
  margin: 0 auto;
  display: grid;
  grid-template-columns: auto 1fr auto;
  align-items: center;
  gap: 26px;
}

.cba-reg-footer ul {
  margin: 0;
  padding: 0;
  list-style: none;
}

.cba-reg-footer .marks__item img {
  width: 128px;
  height: auto;
}

.cba-reg-footer .l-footer__copyright {
  margin: 0;
  color: #10243a;
  font-size: 15px;
}

.cba-reg-footer .footer-link {
  display: flex;
  gap: 34px;
}

.cba-reg-footer .footer-link__target {
  color: #8790a2;
  font-size: 14px;
  font-weight: 700;
  text-decoration: none;
}

@media (max-width: 760px) {
  .cba-reg-header .l-contents,
  .cba-reg-header .navList__wrap,
  .cba-footer-global {
    width: calc(100% - 28px);
  }

  .cba-reg-header .l-header__primarywrap {
    min-height: 0;
    display: block;
    padding-top: 16px;
  }

  .cba-reg-header .l-header__global__links {
    display: none;
  }

  .cba-reg-header .l-header__logo-wrap {
    flex: none;
  }

  .cba-reg-header .logo {
    display: flex;
    flex-wrap: wrap;
    align-items: center;
    gap: 10px;
  }

  .cba-reg-header .header__brandId img {
    width: 86px;
  }

  .cba-reg-header .header__siteId {
    margin-top: 0;
  }

  .cba-reg-header .header__siteId img {
    width: min(240px, 100%);
  }

  .cba-page-id .header__pageIdLink {
    width: min(360px, 100%);
    border-radius: 0;
  }

  .cba-reg-header .header__gNav {
    margin-top: 12px;
    border-top: 1px solid #d1e0e8;
  }

  .cba-reg-header .navList {
    grid-template-columns: repeat(2, 1fr);
  }

  .cba-reg-header .navList__itemLink {
    min-height: 86px;
    gap: 6px;
    font-size: 13px;
  }

  .cba-nav-icon {
    width: 34px;
    height: 34px;
  }

  .cba-footer-global {
    display: block;
  }

  .cba-reg-footer .l-footer__copyright {
    margin-top: 14px;
  }

  .cba-reg-footer .footer-link {
    margin-top: 14px;
    display: block;
  }

  .cba-reg-footer .footer-link__item + .footer-link__item {
    margin-top: 8px;
  }
}

@media (max-width: 860px) {
  .header-inner,
  .footer-inner,
  .two-column {
    display: block;
  }

  .brand {
    min-height: 58px;
  }

  .global-nav {
    padding-bottom: 14px;
  }

  .home-hero {
    min-height: 360px;
  }

  .cba-hero {
    min-height: 680px;
    align-items: start;
  }

  .cba-visual {
    right: 20px;
    top: 340px;
    width: calc(100% - 40px);
    max-width: 520px;
    height: 300px;
    opacity: .92;
    overflow: hidden;
  }

  .assessment-window {
    right: 0;
    width: min(390px, 86vw);
  }

  .feedback-card {
    display: none;
  }

  .line-a {
    width: 300px;
  }

  .line-b {
    width: 260px;
  }

  .line-c {
    width: 150px;
  }

  .topic-grid,
  .article-list,
  .member-list {
    grid-template-columns: 1fr;
  }

  .two-column .text-block + .text-block {
    margin-top: 18px;
  }

  .output-group {
    grid-template-columns: 1fr;
    gap: 6px;
  }

  .footer-nav {
    margin-top: 24px;
  }
}

@media (max-width: 560px) {
  .header-inner,
  .footer-inner,
  .section-inner,
  .section-inner.narrow,
  .home-hero__inner,
  .cba-hero__content {
    width: min(100% - 28px, 1120px);
  }

  .brand {
    align-items: flex-start;
    flex-direction: column;
    gap: 0;
    padding-top: 12px;
  }

  .global-nav,
  .page-nav {
    gap: 8px;
  }

  .page-nav {
    display: grid;
    grid-template-columns: 1fr;
    width: auto;
    margin-left: 14px;
    margin-right: 42px;
    padding-inline: 0;
  }

  .page-nav a {
    min-width: 0;
    width: calc(100vw - 56px);
    display: flex;
    align-items: center;
    justify-content: center;
    min-height: 42px;
    padding: 7px 8px;
    text-align: center;
    white-space: normal;
    overflow-wrap: anywhere;
    line-height: 1.35;
  }

  .global-nav a,
  .page-nav a {
    font-size: 13px;
  }

  .section {
    padding: 56px 0;
  }

  .project-banner,
  .text-block,
  .topic-card,
  .article-card,
  .member-card,
  .notice-panel,
  .collaboration-panel {
    padding: 22px;
  }

  .cba-hero__media::after {
    background:
      linear-gradient(180deg, rgba(247, 251, 253, .98) 0 48%, rgba(247, 251, 253, .72) 100%),
      repeating-linear-gradient(0deg, rgba(0, 103, 177, .035) 0 1px, transparent 1px 28px),
      repeating-linear-gradient(90deg, rgba(0, 103, 177, .035) 0 1px, transparent 1px 28px);
  }

  .project-banner--cba::before {
    display: none;
  }
}

@media (max-width: 900px) {
  .thinking-gnav ul {
    grid-template-columns: repeat(3, 1fr);
  }

  .thinking-gnav a {
    min-height: 96px;
  }

  .thinking-hero__inner {
    grid-template-columns: 1fr;
    gap: 26px;
    padding: 40px 28px 34px;
  }

  .thinking-hero__visual {
    min-height: 300px;
  }

  .cba-visual.cba-visual--thinking {
    position: relative;
    inset: auto;
    right: auto;
    top: auto;
    width: 100%;
    max-width: none;
    height: 300px;
    opacity: 1;
    overflow: visible;
  }

  .cba-visual--thinking .assessment-window {
    left: 0;
    right: auto;
    top: 26px;
    width: min(390px, 100%);
  }

  .thinking-detail,
  .member-names {
    grid-template-columns: 1fr;
  }

  .news-item {
    grid-template-columns: 110px 1fr 28px;
  }

  .news-item .itemDate {
    grid-column: 2;
  }

  .news-item .itemText {
    grid-column: 2;
  }

  .output-table section {
    grid-template-columns: 1fr;
    gap: 6px;
  }
}

@media (max-width: 560px) {
  .thinking-header__inner,
  .thinking-gnav ul,
  .thinking-hero__inner,
  .thinking-contents,
  .thinking-footer__nav {
    width: calc(100% - 28px);
  }

  .thinking-header__logos {
    display: block;
  }

  .thinking-site {
    display: block;
    margin-top: 8px;
  }

  .thinking-page-id {
    padding: 12px 14px;
    border-radius: 0 16px 16px 0;
    font-size: 18px;
  }

  .thinking-gnav ul {
    grid-template-columns: repeat(2, 1fr);
  }

  .thinking-gnav a {
    min-height: 82px;
    font-size: 13px;
  }

  .nav-icon {
    width: 34px;
    height: 34px;
    font-size: 11px;
  }

  .thinking-hero {
    padding-top: 20px;
  }

  .thinking-hero__inner {
    min-height: auto;
    padding: 34px 20px 28px;
  }

  .thinking-hero h2 {
    font-size: clamp(34px, 12vw, 48px);
  }

  .thinking-hero h2 span {
    font-size: .39em;
  }

  .thinking-hero__copy p:last-child,
  .thinking-lead,
  .author-message-like {
    font-size: 16px;
  }

  .thinking-hero__visual {
    min-height: 255px;
    overflow: hidden;
  }

  .cba-visual.cba-visual--thinking {
    height: 255px;
  }

  .cba-visual--thinking .assessment-window {
    width: 100%;
    padding: 48px 16px 16px;
  }

  .aim-list li {
    grid-template-columns: 1fr;
    gap: 12px;
    padding: 22px;
    font-size: 16px;
  }

  .thinking-detail section {
    padding: 22px;
  }

  .news-item {
    grid-template-columns: 1fr 28px;
    gap: 8px 14px;
    padding: 18px 0;
  }

  .news-item .itemCat,
  .news-item .itemDate,
  .news-item .itemText {
    grid-column: 1;
  }

  .news-item::after {
    grid-column: 2;
    grid-row: 1 / span 3;
  }

  .thinking-footer__nav ul {
    grid-template-columns: 1fr;
  }

  .thinking-footer__global {
    display: block;
  }

  .thinking-footer__global small {
    display: block;
    margin-top: 12px;
  }
}
